EXPORTS
	??0CUsbClassControllerBase@@IAE@AAVMUsbClassControllerNotify@@H@Z @ 1 NONAME ; protected: __thiscall CUsbClassControllerBase::CUsbClassControllerBase(class MUsbClassControllerNotify &,int)
	??0CUsbClassControllerIterator@@QAE@AAV?$RPointerArray@VCUsbClassControllerBase@@@@@Z @ 2 NONAME ; public: __thiscall CUsbClassControllerIterator::CUsbClassControllerIterator(class RPointerArray<class CUsbClassControllerBase> &)
	??0CUsbClassControllerPlugIn@@IAE@AAVMUsbClassControllerNotify@@H@Z @ 3 NONAME ; protected: __thiscall CUsbClassControllerPlugIn::CUsbClassControllerPlugIn(class MUsbClassControllerNotify &,int)
	??1CUsbClassControllerBase@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CUsbClassControllerBase::~CUsbClassControllerBase(void)
	??1CUsbClassControllerIterator@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CUsbClassControllerIterator::~CUsbClassControllerIterator(void)
	??1CUsbClassControllerPlugIn@@UAE@XZ @ 6 NONAME ; public: virtual __thiscall CUsbClassControllerPlugIn::~CUsbClassControllerPlugIn(void)
	?Compare@CUsbClassControllerBase@@SAHABV1@0@Z @ 7 NONAME ; public: static int __cdecl CUsbClassControllerBase::Compare(class CUsbClassControllerBase const &,class CUsbClassControllerBase const &)
	?Current@CUsbClassControllerIterator@@QAEPAVCUsbClassControllerBase@@XZ @ 8 NONAME ; public: class CUsbClassControllerBase * __thiscall CUsbClassControllerIterator::Current(void)
	?First@CUsbClassControllerIterator@@QAEHXZ @ 9 NONAME ; public: int __thiscall CUsbClassControllerIterator::First(void)
	?NewL@CUsbClassControllerPlugIn@@SAPAV1@VTUid@@AAVMUsbClassControllerNotify@@@Z @ 10 NONAME ; public: static class CUsbClassControllerPlugIn * __cdecl CUsbClassControllerPlugIn::NewL(class TUid,class MUsbClassControllerNotify &)
	?Next@CUsbClassControllerIterator@@QAEHXZ @ 11 NONAME ; public: int __thiscall CUsbClassControllerIterator::Next(void)
	?Owner@CUsbClassControllerBase@@QBEAAVMUsbClassControllerNotify@@XZ @ 12 NONAME ; public: class MUsbClassControllerNotify & __thiscall CUsbClassControllerBase::Owner(void)const 
	?Previous@CUsbClassControllerIterator@@QAEHXZ @ 13 NONAME ; public: int __thiscall CUsbClassControllerIterator::Previous(void)
	?Seek@CUsbClassControllerIterator@@QAEHPAVCUsbClassControllerBase@@@Z @ 14 NONAME ; public: int __thiscall CUsbClassControllerIterator::Seek(class CUsbClassControllerBase *)
	?StartupPriority@CUsbClassControllerBase@@QBEHXZ @ 15 NONAME ; public: int __thiscall CUsbClassControllerBase::StartupPriority(void)const 
	?State@CUsbClassControllerBase@@QBE?AW4TUsbServiceState@@XZ @ 16 NONAME ; public: enum TUsbServiceState  __thiscall CUsbClassControllerBase::State(void)const 

